%% DPSSEigenvalueGapsizeVsW.m 
% Code to generate data for "The Fast Slepian Transform" Figure 1 Right panel
% Compute transition region DPSS eigenvalues for fixed N and varying W
% After running this script, run DPSSEigenvalueGapsizeVsW_makefig.m to
% generate Figure 1 Right panel
%
% Most recent change - 08/07/2017
%
% Copyright 2017, Santhosh Karnik
%
% This file is part of Fast Slepian Transform (FST) Toolbox version 1.0.
%
%    FST is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FST is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FST.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this code in an academic paper, please cite our paper:
% S. Karnik, Z. Zhu, M. B. Wakin, J. K. Romberg, and M. A. Davenport., 
% The fast Slepian transform, Appl. Comput. Harmon. Anal. (2017), 
% http://dx.doi.org/10.1016/j.acha.2017.07.005

N = 65536; % Fixed value of N (signal length)
vecW = logspace(-14*log10(2),-2*log10(2),10001); % Values of W (half-bandwidth)
vecEpsilon = logspace(-3,-12,4); % Values of epsilon

% Compute transition region DPSS eigenvalues for each value of W and store
% the eigenvalues in an array
% Note: This part will take a while to run
maxgap = ceil((2/pi^2)*log(2*N)*log(2e16)+6)+2;
V = zeros(maxgap,length(vecW));
index = zeros(2,length(vecW));
flag = false(1,length(vecW));
lastwarn('');
for ii = 1:length(vecW),
    W = vecW(ii);
    gapoverestimate = (2/pi^2)*log(2*N)*log(2e16)+6;
    lowerindex = max(1,floor(2*N*W-gapoverestimate/2));
    upperindex = min(N,ceil(2*N*W+gapoverestimate/2));
    [~,lambda] = dpss(N,N*W,[lowerindex,upperindex]);
    V(:,ii) = [lambda;zeros(maxgap-length(lambda),1)];
    index(:,ii) = [lowerindex;upperindex];
    if(~isempty(lastwarn))
        flag(ii) = true;
        lastwarn('');
    end
end

% Save array of transition region eigenvalues (optional)
save('DPSS_Transition_Eigenvalues_W.mat')