%% DPSSEigenvalueGapsizeVsW_makefig.m 
% Code to generate figure for "The Fast Slepian Transform" Figure 1 Right panel
% Plots eigenvalue gapsize vs. W for a fixed N and a few values of epsilon
% Before running this script, run DPSSEigenvalueGapsizeVsW.m to generate 
% the data for Figure 1 Right panel
%
% Most recent change - 08/07/2017
%
% Copyright 2017, Santhosh Karnik
%
% This file is part of Fast Slepian Transform (FST) Toolbox version 1.0.
%
%    FST is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FST is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FST.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this code in an academic paper, please cite our paper:
% S. Karnik, Z. Zhu, M. B. Wakin, J. K. Romberg, and M. A. Davenport., 
% The fast Slepian transform, Appl. Comput. Harmon. Anal. (2017), 
% http://dx.doi.org/10.1016/j.acha.2017.07.005

% Load array of transition region eigenvalues
load('DPSS_Transition_Eigenvalues_W.mat')

% Compute the eigenvalue gapsize for each value of epsilon and N
vecEpsilon = logspace(-3,-12,4);
gapsize = zeros(length(vecW),length(vecEpsilon));
for ii = 1:length(vecW),
    for jj = 1:length(vecEpsilon),
        epsilon = vecEpsilon(jj);
        lambda = V(:,ii);
        gapsize(ii,jj) = nnz(lambda >= epsilon & lambda <= 1-epsilon);
    end
end
asybound = (2/pi^2)*log(N*sin(2*pi*vecW))'*log(1./vecEpsilon-1);

% For each value of epsilon, plot the eigenvalue gapsize vs. W
% Most of the code below is for formatting
ColorRGBvals = [     0,         0,    1.0000;
                     0,    0.5000,         0;
                1.0000,         0,         0;
                     0,    0.7500,    0.7500;
                0.7500,         0,    0.7500;
                0.7500,    0.7500,         0;
                0.2500,    0.2500,    0.2500];
            
figure('Position', [50, 50, 800, 600]);
co = get(gca,'ColorOrder');
set(gca,'ColorOrder',ColorRGBvals([1:length(vecEpsilon),1:length(vecEpsilon)],:),'NextPlot','replacechildren');
semilogx(vecW',gapsize,'-')
set(gca,'xscale','log')

axis([min(vecW),max(vecW),0,5*ceil(max(gapsize(:,end))/5)])
set(gca,'Xtick',[2^(-14)*1.0001,2.^((-13):(-2))]);
set(gca,'XTickLabel',{'2^{-14}','2^{-13}','2^{-12}','2^{-11}','2^{-10}','2^{-9}','2^{-8}','2^{-7}','2^{-6}','2^{-5}','2^{-4}','2^{-3}','2^{-2}'})
set(gca,'XMinorTick','off')
set(gca,'Ytick',0:5:(5*ceil(max(gapsize(:,end))/5)));
set(gca,'fontsize',18)

xlabel('$W$','fontsize',22,'interpreter','latex')
ylabel('$\#\{\ell : \epsilon < \lambda_{N,W}^{(\ell)} < 1-\epsilon\}$','fontsize',22,'interpreter','latex')
title('Eigenvalue Gapsize vs. DPSS Bandwidth for $N = 65536$','fontsize',22,'interpreter','latex')

text(1/16,asybound(end,1)-2,'$\epsilon = 10^{-3}$','fontsize',18,'interpreter','latex')
text(1/16,asybound(end,2)-3,'$\epsilon = 10^{-6}$','fontsize',18,'interpreter','latex')
text(1/16,asybound(end,3)-5,'$\epsilon = 10^{-9}$','fontsize',18,'interpreter','latex')
text(1/16,asybound(end,4)-6,'$\epsilon = 10^{-12}$','fontsize',18,'interpreter','latex')

set(gca, 'LooseInset', [0,0,0,0]);