%% Test_FST_FSP_makefigs.m 
% Code to generate "The Fast Slepian Transform" Figures 2 and 3. 
% Before running this script, run Test_FST_FSP.m to test the Fast Slepian
% Transform and the Fast Slepian Projection for a fixed W (half-bandwidth)
% and varying N and epsilon. 
%
% Most recent change - 08/07/2017
%
% Copyright 2017, Santhosh Karnik
%
% This file is part of Fast Slepian Transform (FST) Toolbox version 1.0.
%
%    FST is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FST is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FST.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this code in an academic paper, please cite our paper:
% S. Karnik, Z. Zhu, M. B. Wakin, J. K. Romberg, and M. A. Davenport., 
% The fast Slepian transform, Appl. Comput. Harmon. Anal. (2017), 
% http://dx.doi.org/10.1016/j.acha.2017.07.005

% Pick appropriate value of W
W = 1/4;
Wstring = '2500';
Wfrac = '\frac{1}{4}';
% W = 1/16;
% Wstring = '0625';
% Wfrac = '\frac{1}{16}';
% W = 1/64;
% Wstring = '0156';
% Wfrac = '\frac{1}{64}';

% Load data
load(['Test_FST_FSP_W',Wstring,'.mat'])

% Stuff for axes and tick marks
plotBoxProj = [8,20,10^(-5.2),10^(0.2)];
plotBoxSetup = [8,20,10^(-3.2),10^(2)];
vecXTick = 8:20;
cellXTickLabel = {'2^8','2^9','2^{10}','2^{11}','2^{12}','2^{13}','2^{14}','2^{15}','2^{16}','2^{17}','2^{18}','2^{19}','2^{20}'};

% Plot Fast Slepian Transform time and Exact Projection time
figure('Position', [50, 50, 800, 600]);
semilogy(log2(vecN(vecN<=Nmax)),Exact_proj_avg_time,'-','linewidth',3,'color',[1,0,1]);
hold on
semilogy(log2(vecN),FST_proj_avg_time(1,:),'-','linewidth',2,'color',[0,0,1]);
semilogy(log2(vecN),FST_proj_avg_time(2,:),':','linewidth',3,'color',[0,0,0]);
semilogy(log2(vecN),FST_proj_avg_time(3,:),'-.','linewidth',2,'color',[0,0.5,0]);
semilogy(log2(vecN),FST_proj_avg_time(4,:),'--','linewidth',2,'color',[1,0,0]);
axis(plotBoxProj)
set(gca,'XTick',vecXTick)
set(gca,'XTickLabel',cellXTickLabel)
set(gca,'YTick',10.^(-5:0))
set(gca,'YTickLabel',{'10^{-5}','10^{-4}','10^{-3}','10^{-2}','10^{-1}','10^{0}'})
set(gca,'FontSize',18)
title(['Slepian Transform Time ($W = ',Wfrac,'$)'],'fontsize',22,'interpreter','latex')
xlabel('vector length $N$','fontsize',22,'interpreter','latex');
ylabel('time (sec)','fontsize',22,'interpreter','latex');
h1 = legend('exact transform','fast transform $\epsilon = 10^{-3}$','fast transform $\epsilon = 10^{-6}$',...
    'fast transform $\epsilon = 10^{-9}$','fast transform $\epsilon = 10^{-12}$');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot Fast Slepian Projection time and Exact Projection time
figure('Position', [50, 50, 800, 600]);
semilogy(log2(vecN(vecN<=Nmax)),Exact_proj_avg_time,'-','linewidth',3,'color',[1,0,1]);
hold on
semilogy(log2(vecN),FSP_proj_avg_time(1,:),'-','linewidth',2,'color',[0,0,1]);
semilogy(log2(vecN),FSP_proj_avg_time(2,:),':','linewidth',3,'color',[0,0,0]);
semilogy(log2(vecN),FSP_proj_avg_time(3,:),'-.','linewidth',2,'color',[0,0.5,0]);
semilogy(log2(vecN),FSP_proj_avg_time(4,:),'--','linewidth',2,'color',[1,0,0]);
axis(plotBoxProj)
set(gca,'XTick',vecXTick)
set(gca,'XTickLabel',cellXTickLabel)
set(gca,'YTick',10.^(-5:0))
set(gca,'YTickLabel',{'10^{-5}','10^{-4}','10^{-3}','10^{-2}','10^{-1}','10^{0}'})
set(gca,'FontSize',18)
title(['Slepian Projection Time ($W = ',Wfrac,'$)'],'fontsize',22,'interpreter','latex')
xlabel('vector length $N$','fontsize',22,'interpreter','latex');
ylabel('time (sec)','fontsize',22,'interpreter','latex');
h1 = legend('exact projection','fast projection $\epsilon = 10^{-3}$','fast projection $\epsilon = 10^{-6}$',...
    'fast projection $\epsilon = 10^{-9}$','fast projection $\epsilon = 10^{-12}$');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot Fast Slepian Transform setup time and Exact Projection setup time
figure('Position', [50, 50, 800, 600]);
semilogy(log2(vecN(vecN<=Nmax)),Exact_setup_avg_time,'-','linewidth',3,'color',[1,0,1]);
hold on
semilogy(log2(vecN),FST_setup_avg_time(1,:),'-','linewidth',2,'color',[0,0,1]);
semilogy(log2(vecN),FST_setup_avg_time(2,:),':','linewidth',3,'color',[0,0,0]);
semilogy(log2(vecN),FST_setup_avg_time(3,:),'-.','linewidth',2,'color',[0,0.5,0]);
semilogy(log2(vecN),FST_setup_avg_time(4,:),'--','linewidth',2,'color',[1,0,0]);
axis(plotBoxSetup)
set(gca,'XTick',vecXTick)
set(gca,'XTickLabel',cellXTickLabel)
set(gca,'YTick',10.^(-3:2))
set(gca,'YTickLabel',{'10^{-3}','10^{-2}','10^{-1}','10^{0}','10^{1}','10^{2}'})
set(gca,'FontSize',18)
title(['Slepian Transform Setup Time ($W = ',Wfrac,'$)'],'fontsize',22,'interpreter','latex')
xlabel('vector length $N$','fontsize',22,'interpreter','latex');
ylabel('time (sec)','fontsize',22,'interpreter','latex');
h1 = legend('exact transform','fast transform $\epsilon = 10^{-3}$','fast transform $\epsilon = 10^{-6}$',...
    'fast transform $\epsilon = 10^{-9}$','fast transform $\epsilon = 10^{-12}$');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot Fast Slepian Projection setup time and Exact Projection setup time
figure('Position', [50, 50, 800, 600]);
semilogy(log2(vecN(vecN<=Nmax)),Exact_setup_avg_time,'-','linewidth',3,'color',[1,0,1]);
hold on
semilogy(log2(vecN),FSP_setup_avg_time(1,:),'-','linewidth',2,'color',[0,0,1]);
semilogy(log2(vecN),FSP_setup_avg_time(2,:),':','linewidth',3,'color',[0,0,0]);
semilogy(log2(vecN),FSP_setup_avg_time(3,:),'-.','linewidth',2,'color',[0,0.5,0]);
semilogy(log2(vecN),FSP_setup_avg_time(4,:),'--','linewidth',2,'color',[1,0,0]);
axis(plotBoxSetup)
set(gca,'XTick',vecXTick)
set(gca,'XTickLabel',cellXTickLabel)
set(gca,'YTick',10.^(-3:2))
set(gca,'YTickLabel',{'10^{-3}','10^{-2}','10^{-1}','10^{0}','10^{1}','10^{2}'})
set(gca,'FontSize',18)
title(['Slepian Projection Setup Time ($W = ',Wfrac,'$)'],'fontsize',22,'interpreter','latex')
xlabel('vector length $N$','fontsize',22,'interpreter','latex');
ylabel('time (sec)','fontsize',22,'interpreter','latex');
h1 = legend('exact projection','fast projection $\epsilon = 10^{-3}$','fast projection $\epsilon = 10^{-6}$',...
    'fast projection $\epsilon = 10^{-9}$','fast projection $\epsilon = 10^{-12}$');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);